@@ -1,7 +1,9 @@
 """Utils for dealing with `Optional` types."""
-from typing import Callable, Optional, TypeVar
+from typing import Callable, Optional, TypeVar, Union
 
-__all__ = ["maybe_apply", "unwrap"]
+from .lib import Some
+
+__all__ = ["Maybe", "Some", "maybe_apply", "unwrap"]
 
 T = TypeVar("T")
 
@@ -22,3 +24,6 @@ def unwrap(value: Optional[T], default: T) -> T:
 def maybe_apply(value: Optional[T], func: Callable[[T], Optional[T]]) -> Optional[T]:
     """Apply a function to a value if the value is not `None`."""
     return func(value) if value is not None else None
+
+
+Maybe = Union[Some[T], None]
